==> monaco-vscode-view-common-service-override-11.1.1.tgz: package/vscode/src/vs/workbench/contrib/limitIndicator/browser/limitIndicator.contribution.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { Disposable } from 'vscode/vscode/vs/base/common/lifecycle';
import Severity$1 from 'vscode/vscode/vs/base/common/severity';
import { getCodeEditor } from 'vscode/vscode/vs/editor/browser/editorBrowser';
import { IEditorService } from 'vscode/vscode/vs/workbench/services/editor/common/editorService.service';
import { ILanguageStatusService } from 'vscode/vscode/vs/workbench/services/languageStatus/common/languageStatusService.service';
import { Registry } from 'vscode/vscode/vs/platform/registry/common/platform';
import { Extensions } from 'vscode/vscode/vs/workbench/common/contributions';
import { localize } from 'vscode/vscode/vs/nls';
import { FoldingController } from 'vscode/vscode/vs/editor/contrib/folding/browser/folding';
import { ColorDetector } from 'vscode/vscode/vs/editor/contrib/colorPicker/browser/colorDetector';

const openSettingsCommand = 'workbench.action.openSettings';
const configureSettingsLabel = ( localize(4199, "Configure"));
let LimitIndicatorContribution = class LimitIndicatorContribution extends Disposable {
    constructor(editorService, languageStatusService) {
        super();
        const accessors = [( (new ColorDecorationAccessor())), ( (new FoldingRangeAccessor()))];
        const statusEntries = ( (accessors.map(
            indicator => ( (new LanguageStatusEntry(languageStatusService, indicator)))
        )));
        statusEntries.forEach(entry => this._register(entry));
        let control;
        const onActiveEditorChanged = () => {
            const activeControl = editorService.activeTextEditorControl;
            if (activeControl === control) {
                return;
            }
            control = activeControl;
            const editor = getCodeEditor(activeControl);
            statusEntries.forEach(statusEntry => statusEntry.onActiveEditorChanged(editor));
        };
        this._register(editorService.onDidActiveEditorChange(onActiveEditorChanged));
        onActiveEditorChanged();
    }
};
LimitIndicatorContribution = ( (__decorate([
    ( (__param(0, IEditorService))),
    ( (__param(1, ILanguageStatusService)))
], LimitIndicatorContribution)));
class ColorDecorationAccessor {
    constructor() {
        this.id = 'decoratorsLimitInfo';
        this.name = ( localize(4200, 'Color Decorator Status'));
        this.label = ( localize(4201, 'Color Decorators'));
        this.source = ( localize(4202, 'Color Decorators'));
        this.settingsId = 'editor.colorDecoratorsLimit';
    }
    getLimitReporter(editor) {
        return ColorDetector.get(editor)?.limitReporter;
    }
}
class FoldingRangeAccessor {
    constructor() {
        this.id = 'foldingLimitInfo';
        this.name = ( localize(4203, 'Folding Status'));
        this.label = ( localize(4204, 'Folding Ranges'));
        this.source = ( localize(4205, 'Folding'));
        this.settingsId = 'editor.foldingMaximumRegions';
    }
    getLimitReporter(editor) {
        return FoldingController.get(editor)?.limitReporter;
    }
}
class LanguageStatusEntry {
    constructor(languageStatusService, accessor) {
        this.languageStatusService = languageStatusService;
        this.accessor = accessor;
    }
    onActiveEditorChanged(editor) {
        if (this._indicatorChangeListener) {
            this._indicatorChangeListener.dispose();
            this._indicatorChangeListener = undefined;
        }
        let info;
        if (editor) {
            info = this.accessor.getLimitReporter(editor);
        }
        this.updateStatusItem(info);
        if (info) {
            this._indicatorChangeListener = info.onDidChange(_ => {
                this.updateStatusItem(info);
            });
            return true;
        }
        return false;
    }
    updateStatusItem(info) {
        if (this._limitStatusItem) {
            this._limitStatusItem.dispose();
            this._limitStatusItem = undefined;
        }
        if (info && info.limited !== false) {
            const status = {
                id: this.accessor.id,
                selector: '*',
                name: this.accessor.name,
                severity: Severity$1.Warning,
                label: this.accessor.label,
                detail: ( localize(4206, 'only {0} shown for performance reasons', info.limited)),
                command: { id: openSettingsCommand, arguments: [this.accessor.settingsId], title: configureSettingsLabel },
                accessibilityInfo: undefined,
                source: this.accessor.source,
                busy: false
            };
            this._limitStatusItem = this.languageStatusService.addStatus(status);
        }
    }
    dispose() {
        this._limitStatusItem = undefined;
        this._indicatorChangeListener = undefined;
    }
}
( (Registry.as(Extensions.Workbench))).registerWorkbenchContribution(LimitIndicatorContribution, 3 );

export { LimitIndicatorContribution };

==> monaco-vscode-view-common-service-override-12.0.1.tgz: package/vscode/src/vs/workbench/contrib/limitIndicator/browser/limitIndicator.contribution.js <==

import { __decorate, __param } from 'vscode/external/tslib/tslib.es6';
import { Disposable } from 'vscode/vscode/vs/base/common/lifecycle';
import Severity from 'vscode/vscode/vs/base/common/severity';
import { getCodeEditor } from 'vscode/vscode/vs/editor/browser/editorBrowser';
import { IEditorService } from 'vscode/vscode/vs/workbench/services/editor/common/editorService.service';
import { ILanguageStatusService } from 'vscode/vscode/vs/workbench/services/languageStatus/common/languageStatusService.service';
import { Registry } from 'vscode/vscode/vs/platform/registry/common/platform';
import { Extensions } from 'vscode/vscode/vs/workbench/common/contributions';
import { LifecyclePhase } from 'vscode/vscode/vs/workbench/services/lifecycle/common/lifecycle';
import { localize } from 'vscode/vscode/vs/nls';
import { FoldingController } from 'vscode/vscode/vs/editor/contrib/folding/browser/folding';
import { ColorDetector } from 'vscode/vscode/vs/editor/contrib/colorPicker/browser/colorDetector';

const openSettingsCommand = 'workbench.action.openSettings';
const configureSettingsLabel = ( localize(6945, "Configure"));
let LimitIndicatorContribution = class LimitIndicatorContribution extends Disposable {
    constructor(editorService, languageStatusService) {
        super();
        const accessors = [( new ColorDecorationAccessor()), ( new FoldingRangeAccessor())];
        const statusEntries = ( accessors.map(indicator => ( new LanguageStatusEntry(languageStatusService, indicator))));
        statusEntries.forEach(entry => this._register(entry));
        let control;
        const onActiveEditorChanged = () => {
            const activeControl = editorService.activeTextEditorControl;
            if (activeControl === control) {
                return;
            }
            control = activeControl;
            const editor = getCodeEditor(activeControl);
            statusEntries.forEach(statusEntry => statusEntry.onActiveEditorChanged(editor));
        };
        this._register(editorService.onDidActiveEditorChange(onActiveEditorChanged));
        onActiveEditorChanged();
    }
};
LimitIndicatorContribution = ( __decorate([
    ( __param(0, IEditorService)),
    ( __param(1, ILanguageStatusService))
], LimitIndicatorContribution));
class ColorDecorationAccessor {
    constructor() {
        this.id = 'decoratorsLimitInfo';
        this.name = ( localize(6946, 'Color Decorator Status'));
        this.label = ( localize(6947, 'Color Decorators'));
        this.source = ( localize(6948, 'Color Decorators'));
        this.settingsId = 'editor.colorDecoratorsLimit';
    }
    getLimitReporter(editor) {
        return ColorDetector.get(editor)?.limitReporter;
    }
}
class FoldingRangeAccessor {
    constructor() {
        this.id = 'foldingLimitInfo';
        this.name = ( localize(6949, 'Folding Status'));
        this.label = ( localize(6950, 'Folding Ranges'));
        this.source = ( localize(6951, 'Folding'));
        this.settingsId = 'editor.foldingMaximumRegions';
    }
    getLimitReporter(editor) {
        return FoldingController.get(editor)?.limitReporter;
    }
}
class LanguageStatusEntry {
    constructor(languageStatusService, accessor) {
        this.languageStatusService = languageStatusService;
        this.accessor = accessor;
    }
    onActiveEditorChanged(editor) {
        if (this._indicatorChangeListener) {
            this._indicatorChangeListener.dispose();
            this._indicatorChangeListener = undefined;
        }
        let info;
        if (editor) {
            info = this.accessor.getLimitReporter(editor);
        }
        this.updateStatusItem(info);
        if (info) {
            this._indicatorChangeListener = info.onDidChange(_ => {
                this.updateStatusItem(info);
            });
            return true;
        }
        return false;
    }
    updateStatusItem(info) {
        if (this._limitStatusItem) {
            this._limitStatusItem.dispose();
            this._limitStatusItem = undefined;
        }
        if (info && info.limited !== false) {
            const status = {
                id: this.accessor.id,
                selector: '*',
                name: this.accessor.name,
                severity: Severity.Warning,
                label: this.accessor.label,
                detail: ( localize(6952, 'only {0} shown for performance reasons', info.limited)),
                command: { id: openSettingsCommand, arguments: [this.accessor.settingsId], title: configureSettingsLabel },
                accessibilityInfo: undefined,
                source: this.accessor.source,
                busy: false
            };
            this._limitStatusItem = this.languageStatusService.addStatus(status);
        }
    }
    dispose() {
        this._limitStatusItem = undefined;
        this._indicatorChangeListener = undefined;
    }
}
( Registry.as(Extensions.Workbench)).registerWorkbenchContribution(LimitIndicatorContribution, LifecyclePhase.Restored);

export { LimitIndicatorContribution };
